@@ -27,9 +27,8 @@ PROJECT_TEMPLATE_DIRS = ['project/templates',]
 
 #context processors
 PROJECT_TEMPLATE_CONTEXT_PROCESSORS = [
-    ]
-    #'project.utils.context_processors.settings_constants',
-
+    'backstage.project.utils.context_processors.settings_constants',
+]
 
 #automatically convert spaces to underscores
 UNDERSCORIFY=True
